import logging


logger = logging.getLogger(__name__)


def dot_items_globally():
    def global__setattr__decorator(scrapy__setattr__):
        def dot__setattr__(self, name, value):
            if name.startswith('_'):
                scrapy__setattr__(self, name, value)
            else:
                self.__setitem__(name, value)
        return dot__setattr__

    try:
        import scrapy
        scrapy.Item.__getattr__ = lambda self, name: self.__getitem__(name)
        scrapy.Item.__setattr__ = global__setattr__decorator(scrapy.Item.__setattr__)
        logger.debug('scrapy-dot-items were configured globally')
    except ModuleNotFoundError as e:
        logger.exception(e)
        logger.error('In order to use this library you need to have "scrapy" installed')





def dot_item(scrapy_item_class):
    """
    A decorator for scrapy items
    @dot_item
    class YourScrapyItem(scrapy.Item):

    :param scrapy_item_class:
    :return:
    """
    class ScrapyDotItem(scrapy_item_class):
        def __getattr__(self, key):
            return super().__getitem__(key)

        def __setattr__(self, name, value):
            print(f'{name}, {value}')
            print(name.startswith('_'))
            if not name.startswith('_'):
                super().__setitem__(name, value)
            else:
                super().__setattr__(name, value)
    return ScrapyDotItem



from setuptools import setup
import subprocess


version = (
    subprocess.run(["git", "describe", "--tags"], stdout=subprocess.PIPE)
    .stdout.decode("utf-8")
    .strip()
)


with open('README.md', 'r') as fh:
    long_description = fh.read()


setup(
    name='scrapy-dot-items',
    packages=['scrapy_dot_items',],
    version=version,
    description='A Scrapy addon that allows to access arguments via the dot',
    url='https://github.com/sgerodes/scrapy-items',
    author='Sergey Gerodes',
    author_email='sgerodes@gmail.com',
    long_description=long_description,
    long_description_content_type='text/markdown',
    py_modules=['some_module'],
    package_dir={'': 'src'},
    keywords=['python', 'scrapy', 'scrapy-items', 'dot-items', 'dot'],
    python_requires='>=3.7',
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    install_requires=[]
)
